@@ -4,8 +4,11 @@ import os
 import signal
 
 
-def expected_text(child, text, timeout):
-    return 0 == child.expect_exact([text, TIMEOUT, EOF], timeout)
+def expected_text(child, pattern, timeout):
+    if child is None:
+        raise RuntimeError("expected_text called without having previously "
+                           "run a child process to interact with")
+    return 0 == child.expect([pattern, TIMEOUT, EOF], timeout)
 
 
 def setup(context):
@@ -13,6 +16,7 @@ def setup(context):
     context.child = None
     context.children = {}
     context.cwd = os.getcwd()
+    context._cwd = context.cwd
     context.args = None
     context.timeout = 2
 
@@ -32,3 +36,4 @@ def teardown(context):
     context.child = None
     context.children = {}
     context.args = None
+    os.chdir(context._cwd)
